==> mediawiki-1.14.0.tgz: mediawiki/languages/messages/MessagesIe.php <==
<?php
/** Interlingue (Interlingue)
 *
 * @ingroup Language
 * @file
 *
 * @author Jmb
 * @author Malafaya
 * @author Remember the dot
 * @author לערי ריינהארט
 */

$messages = array(
# Dates
'sunday'        => 'soledí',
'monday'        => 'lunedí',
'tuesday'       => 'mardí',
'wednesday'     => 'mercurdí',
'thursday'      => 'jovedí',
'friday'        => 'venerdí',
'saturday'      => 'saturdí',
'sun'           => 'sol',
'mon'           => 'lun',
'tue'           => 'mar',
'wed'           => 'mer',
'thu'           => 'jov',
'fri'           => 'ven',
'sat'           => 'sat',
'january'       => 'januar',
'february'      => 'februar',
'march'         => 'marte',
'april'         => 'april',
'may_long'      => 'may',
'june'          => 'junio',
'july'          => 'julí',
'august'        => 'august',
'september'     => 'septembre',
'october'       => 'octobre',
'november'      => 'novembre',
'december'      => 'decembre',
'january-gen'   => 'januar',
'february-gen'  => 'februar',
'march-gen'     => 'marte',
'april-gen'     => 'april',
'may-gen'       => 'may',
'june-gen'      => 'junio',
'july-gen'      => 'juli',
'august-gen'    => 'august',
'september-gen' => 'septembre',
'october-gen'   => 'octobre',
'november-gen'  => 'novembre',
'december-gen'  => 'decembre',
'jan'           => 'jan',
'feb'           => 'feb',
'mar'           => 'mar',
'apr'           => 'apr',
'may'           => 'may',
'jun'           => 'jun',
'jul'           => 'jul',
'aug'           => 'aug',
'sep'           => 'sep',
'oct'           => 'oct',
'nov'           => 'nov',
'dec'           => 'dec',

# Categories related messages
'pagecategories'         => '{{PLURAL:$1|Categorie|Categories}}',
'category_header'        => 'Articules in categorie "$1"',
'listingcontinuesabbrev' => 'cont.',

'mainpagetext' => "<big>'''Software del wiki installat con successe.'''</big>",

'about'          => 'Apropó',
'article'        => 'Articul',
'newwindow'      => '(aperte un nov fenestre)',
'cancel'         => 'Anullar',
'qbfind'         => 'Serchar',
'qbedit'         => 'Modificar',
'qbpageoptions'  => 'Págine de optiones',
'qbpageinfo'     => 'Págine de information',
'qbspecialpages' => 'Special págines',
'moredotdotdot'  => 'Plu mult...',
'mytalk'         => 'Mi discussion',
'anontalk'       => 'Discussion por ti ci IP',
'and'            => '&#32;e',

'errorpagetitle'   => 'Errore',
'returnto'         => 'Retornar a $1.',
'tagline'          => 'Ex {{SITENAME}}',
'help'             => 'Auxilie',
'search'           => 'Serchar',
'searchbutton'     => 'Sercha',
'go'               => 'Ear',
'searcharticle'    => 'Vade',
'history'          => 'Historie',
'history_short'    => 'Historie',
'printableversion' => 'Printabil version',
'edit'             => 'Modificar',
'editthispage'     => 'Modificar ti págine',
'delete'           => 'Deleter',
'deletethispage'   => 'Deleter ti págine',
'undelete_short'   => 'Restaurar {{PLURAL:$1|1 modification|$1 modificationes}}',
'protect'          => 'Protecter',
'unprotect'        => 'Deprotecter',
'newpage'          => 'Nov págine',
'talkpage'         => 'Discusser ti págine',
'talkpagelinktext' => 'Discussion',
'specialpage'      => 'Special Págine',
'personaltools'    => 'Utensiles personal',
'postcomment'      => 'Impostar un comenta',
'articlepage'      => 'Vider li articul',
'talk'             => 'Discussion',
'toolbox'          => 'Buxe de utensiles',
'userpage'         => 'Vider págine del usator',
'imagepage'        => 'Vider págine del image',
'viewtalkpage'     => 'Vider li discussion',
'redirectedfrom'   => '(Redirectet de $1)',
'viewcount'        => 'Ti págine ha esset consultat {{PLURAL:$1|un vez|$1 vezes}}.',
'protectedpage'    => 'Un protectet págine',
'jumptonavigation' => 'navigation',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Apropó de {{SITENAME}}',
'aboutpage'            => 'Project:Apropó',
'copyright'            => 'Contenete disponibil sub $1.',
'disclaimers'          => 'Advertimentes',
'edithelp'             => 'Auxilie',
'edithelppage'         => 'Help:Qualmen modificar un págine',
'helppage'             => 'Help:Auxilie',
'mainpage'             => 'Principal págine',
'mainpage-description' => 'Principal págine',
'portal'               => 'Págine del comunité',
'portal-url'           => 'Project:Págine del comunité',

'youhavenewmessages' => 'Vu have $1 ($2).',
'newmessageslink'    => 'nov missages',
'editsection'        => 'modificar',
'editold'            => 'redacter',
'editsectionhint'    => 'Modification de section: $1',
'toc'                => 'Tabelle de contenetes',
'showtoc'            => 'monstrar',
'hidetoc'            => 'celar',
'viewdeleted'        => 'Vider $1?',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Págine',
'nstab-user'      => 'Usator',
'nstab-project'   => 'Págine de projecte',
'nstab-mediawiki' => 'Missage',
'nstab-template'  => 'Modelle',
'nstab-help'      => 'Auxilie',
'nstab-category'  => 'Categorie',

# General errors
'error'      => 'Erra',
'viewsource' => 'Vider fonte',

# Login and logout pages
'logouttitle'                => 'Fine de session',
'logouttext'                 => 'Vu ha terminat vor session.
Vu posse continuar usar {{SITENAME}} anonimimen, o vu posse aperter un session denov quam li sam usator o quam un diferent usator.',
'loginpagetitle'             => 'Registrar se/Intrar',
'yourname'                   => 'Vor nómine usatori:',
'yourpassword'               => 'Vor passa-parol:',
'yourpasswordagain'          => 'Tippa denov vor passa-parol',
'remembermypassword'         => 'Memorar mi passa-parol (per cookie)',
'login'                      => 'Aperter session',
'nav-login-createaccount'    => 'Crear un conto o intrar',
'loginprompt'                => 'Cookies deve esser permisset por intrar in {{SITENAME}}.',
'userlogin'                  => 'Crear un conto o intrar',
'logout'                     => 'Surtir',
'userlogout'                 => 'Surtir',
'notloggedin'                => 'Vu ne ha intrat',
'createaccount'              => 'Crear un nov conto',
'gotaccountlink'             => 'Intrar',
'badretype'                  => 'Li passa-paroles queles vu tippat ne es identic.',
'youremail'                  => 'Vor ret-adresse:',
'loginerror'                 => 'Erra in initiation del session',
'nocookieslogin'             => '{{SITENAME}} utilisa cookies por far intrar usatores. Vu nu ne permisse cookies. Ples permisser les e provar denov.',
'loginsuccesstitle'          => 'Apertion de session successosi',
'loginsuccess'               => 'Vu ha apertet vor session in {{SITENAME}} quam "$1".',
'wrongpassword'              => 'Li passa-parol quel vu scrit es íncorect. Prova denov.',
'mailmypassword'             => 'Invia me un nov passa-parol per electronic post',
'acct_creation_throttle_hit' => 'Vu ja ha creat $1 contos. Vu ne posse crear pli mult quam to.',
'loginlanguagelabel'         => 'Lingue: $1',

# Password reset dialog
'oldpassword' => 'Anteyan passa-parol:',
'newpassword' => 'Nov passa-parol:',
'retypenew'   => 'Confirmar nov passa-parol',

# Edit pages
'summary'          => 'Resumate:',
'minoredit'        => 'Modification minori',
'watchthis'        => 'Sequer ti articul',
'savearticle'      => 'Conservar págine',
'preview'          => 'Previder',
'showpreview'      => 'Previder págine',
'loginreqtitle'    => 'Apertion de session obligatori',
'accmailtitle'     => 'Li passa-parol es inviat.',
'accmailtext'      => "Li passa-parol por '$1' ha esset inviat a $2.",
'newarticle'       => '(Nov)',
'editing'          => 'Modification de $1',
'editingsection'   => 'modification de $1 (section)',
'editingcomment'   => 'modification de $1 (comenta)',
'copyrightwarning' => "Omni contributiones a {{SITENAME}} es considerat quam publicat sub li termines del $2 (ples vider $1 por plu mult detallies). Si vu ne vole que vor ovres mey esser modificat e distribuet secun arbitrie, ples ne inviar les. Adplu, ples contribuer solmen vor propri ovres o ovres ex un fonte quel es líber de jures. '''NE UTILISA OVRES SUB JURE EDITORIAL SIN DEFINITIV AUTORISATION!'''",

# Diffs
'lineno' => 'Linea $1:',

# Search results
'viewprevnext'   => 'Vider ($1) ($2) ($3)',
'searchhelp-url' => 'Help:Auxilie',

# Preferences page
'preferences'    => 'Preferenties',
'mypreferences'  => 'Mi preferenties',
'prefsnologin'   => 'Vu ne ha intrat',
'qbsettings'     => 'Personalisation del barre de utensiles',
'changepassword' => 'Modificar passa-parol',
'saveprefs'      => 'Conservar preferenties',

# Groups
'group-user' => 'Usatores',

'group-user-member' => 'Usator',

'grouppage-user' => '{{ns:project}}:Usatores',

# Recent changes
'nchanges'          => '$1 {{PLURAL:$1|change|changes}}',
'recentchanges'     => 'Recent modificationes',
'recentchangestext' => 'Seque sur ti-ci págine li ultim modificationes al wiki.',
'rclistfrom'        => 'Monstrar li nov modificationes desde $1.',
'rcshowhideminor'   => '$1 modificationes minori',
'rcshowhidemine'    => '$1 mi redactiones',
'rclinks'           => 'Monstrar li $1 ultim modificationes fat durante li $2 ultim dies<br/ >$3.',
'diff'              => 'dif',
'hist'              => 'hist',
'hide'              => 'Celar',
'show'              => 'Monstrar',
'minoreditletter'   => 'm',

# Recent changes linked
'recentchangeslinked' => 'Relatet modificationes',

# Upload
'upload'    => 'Cargar file',
'uploadbtn' => 'Cargar file',
'filedesc'  => 'Descrition',
'savefile'  => 'Conservar file',

# Special:ListFiles
'listfiles' => 'Liste de images',

# File description page
'filehist-comment' => 'Comenta',

# Random page
'randompage' => 'Págine in hasarde',

# Statistics
'statistics' => 'Statisticas',

# Miscellaneous special pages
'ncategories'             => '$1 {{PLURAL:$1|categorie|categories}}',
'lonelypages'             => 'Orfani págines',
'uncategorizedpages'      => 'Págines sin categories',
'uncategorizedcategories' => 'Categories sin categories',
'unusedimages'            => 'Orfani images',
'wantedpages'             => 'Li max demandat págines',
'shortpages'              => 'Curt págines',
'longpages'               => 'Long págines',
'deadendpages'            => 'Págines sin exeada',
'listusers'               => 'Liste de usatores',
'newpages'                => 'Nov págines',
'ancientpages'            => 'Li max old págines',
'move'                    => 'Mover',

# Book sources
'booksources' => 'Librari fontes',

# Special:Log
'specialloguserlabel'  => 'Usator:',
'speciallogtitlelabel' => 'Titul:',

# Special:AllPages
'allpages'       => 'Omni págines',
'alphaindexline' => '$1 a $2',
'allarticles'    => 'Omni págines',
'allpagessubmit' => 'Vade',

# Special:Categories
'categories' => 'Categories',

# Watchlist
'watchlist'      => 'Liste de sequet págines',
'addedwatch'     => 'Adjuntet al liste',
'addedwatchtext' => "Li págine ''[[$1]]'' ha esset adjuntet a vor [[Special:Watchlist|liste de sequet págines]]. Li proxim modificationes de ti ci págine e del associat págine de discussion va esser listat ci, e li págine va aperir '''aspessat''' in li [[Special:RecentChanges|liste de recent modificationes]] por esser trovat plu facilmen. Por supresser ti ci págine ex vor liste, ples claccar sur « Ne plu sequer » in li cadre de navigation.",
'watch'          => 'Sequer',
'watchthispage'  => 'Sequer ti págine',

# Delete
'deletepage'            => 'Deleter págine',
'actioncomplete'        => 'Supression efectuat',
'deletecomment'         => 'Motive de deletion:',
'deleteotherreason'     => 'Altri/suplementari motive:',
'deletereasonotherlist' => 'Altri motive',

# Protect
'prot_1movedto2'   => '[[$1]] moet a [[$2]]',
'protectcomment'   => 'Comenta:',
'restriction-type' => 'Permission:',

# Namespace form on various pages
'blanknamespace' => '(Principal)',

# Contributions
'mycontris' => 'Mi contributiones',

# What links here
'whatlinkshere' => 'Ligat págines',

# Block/unblock
'ipblocklist'  => 'Blocat adresses e usatores',
'contribslink' => 'contribs',

# Move page
'movearticle' => 'Moer págine:',
'movenologin' => 'Vu ne ha intrat',
'movepagebtn' => 'Moer págine',
'movedto'     => 'moet a',
'1movedto2'   => '[[$1]] moet a [[$2]]',
'movereason'  => 'Motive:',

# Export
'export' => 'Exportar págines',

# Namespace 8 related
'allmessages' => 'Liste del missages del sistema',

# Tooltip help for the actions
'tooltip-pt-mytalk'      => 'Mi discussion',
'tooltip-pt-preferences' => 'Mi preferenties',
'tooltip-ca-delete'      => 'Deleter ti págine',
'tooltip-ca-move'        => 'Moer ti págine',
'tooltip-n-mainpage'     => 'Visita li Principal págine',
'tooltip-t-specialpages' => 'Liste de omni special págines',

# Special:NewFiles
'newimages' => 'Galerie de nov images',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'omni',
'namespacesall' => 'omni',
'monthsall'     => 'omni',

# Special:Version
'version' => 'Version', # Not used as normal message but as header for the special page itself

# Special:SpecialPages
'specialpages' => 'Special págines',

);

==> mediawiki-1.15.1.tgz: mediawiki/languages/messages/MessagesIe.php <==
<?php
/** Interlingue (Interlingue)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Jmb
 * @author Malafaya
 * @author Remember the dot
 * @author Valodnieks
 * @author לערי ריינהארט
 */

$messages = array(
'underline-always' => 'Sempre',
'underline-never'  => 'Nequande',

# Dates
'sunday'        => 'soledí',
'monday'        => 'lunedí',
'tuesday'       => 'mardí',
'wednesday'     => 'mercurdí',
'thursday'      => 'jovedí',
'friday'        => 'venerdí',
'saturday'      => 'saturdí',
'sun'           => 'sol',
'mon'           => 'lun',
'tue'           => 'mar',
'wed'           => 'mer',
'thu'           => 'jov',
'fri'           => 'ven',
'sat'           => 'sat',
'january'       => 'januar',
'february'      => 'februar',
'march'         => 'marte',
'april'         => 'april',
'may_long'      => 'may',
'june'          => 'junio',
'july'          => 'julí',
'august'        => 'august',
'september'     => 'septembre',
'october'       => 'octobre',
'november'      => 'novembre',
'december'      => 'decembre',
'january-gen'   => 'januar',
'february-gen'  => 'februar',
'march-gen'     => 'marte',
'april-gen'     => 'april',
'may-gen'       => 'may',
'june-gen'      => 'junio',
'july-gen'      => 'juli',
'august-gen'    => 'august',
'september-gen' => 'septembre',
'october-gen'   => 'octobre',
'november-gen'  => 'novembre',
'december-gen'  => 'decembre',
'jan'           => 'jan',
'feb'           => 'feb',
'mar'           => 'mar',
'apr'           => 'apr',
'may'           => 'may',
'jun'           => 'jun',
'jul'           => 'jul',
'aug'           => 'aug',
'sep'           => 'sep',
'oct'           => 'oct',
'nov'           => 'nov',
'dec'           => 'dec',

# Categories related messages
'pagecategories'         => '{{PLURAL:$1|Categorie|Categories}}',
'category_header'        => 'Articules in categorie "$1"',
'listingcontinuesabbrev' => 'cont.',

'mainpagetext' => "<big>'''Software del wiki installat con successe.'''</big>",

'about'          => 'Apropó',
'article'        => 'Articul',
'newwindow'      => '(aperte un nov fenestre)',
'cancel'         => 'Anullar',
'qbfind'         => 'Serchar',
'qbedit'         => 'Modificar',
'qbpageoptions'  => 'Págine de optiones',
'qbpageinfo'     => 'Págine de information',
'qbspecialpages' => 'Special págines',
'moredotdotdot'  => 'Plu mult...',
'mytalk'         => 'Mi discussion',
'anontalk'       => 'Discussion por ti ci IP',
'and'            => '&#32;e',

'errorpagetitle'   => 'Errore',
'returnto'         => 'Retornar a $1.',
'tagline'          => 'Ex {{SITENAME}}',
'help'             => 'Auxilie',
'search'           => 'Serchar',
'searchbutton'     => 'Sercha',
'go'               => 'Ear',
'searcharticle'    => 'Vade',
'history'          => 'Historie',
'history_short'    => 'Historie',
'printableversion' => 'Printabil version',
'edit'             => 'Modificar',
'editthispage'     => 'Modificar ti págine',
'delete'           => 'Deleter',
'deletethispage'   => 'Deleter ti págine',
'undelete_short'   => 'Restaurar {{PLURAL:$1|1 modification|$1 modificationes}}',
'protect'          => 'Protecter',
'unprotect'        => 'Deprotecter',
'newpage'          => 'Nov págine',
'talkpage'         => 'Discusser ti págine',
'talkpagelinktext' => 'Discussion',
'specialpage'      => 'Special Págine',
'personaltools'    => 'Utensiles personal',
'postcomment'      => 'Impostar un comenta',
'articlepage'      => 'Vider li articul',
'talk'             => 'Discussion',
'toolbox'          => 'Buxe de utensiles',
'userpage'         => 'Vider págine del usator',
'imagepage'        => 'Vider págine del image',
'viewtalkpage'     => 'Vider li discussion',
'redirectedfrom'   => '(Redirectet de $1)',
'viewcount'        => 'Ti págine ha esset consultat {{PLURAL:$1|un vez|$1 vezes}}.',
'protectedpage'    => 'Un protectet págine',
'jumptonavigation' => 'navigation',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Apropó de {{SITENAME}}',
'aboutpage'            => 'Project:Apropó',
'copyright'            => 'Contenete disponibil sub $1.',
'disclaimers'          => 'Advertimentes',
'edithelp'             => 'Auxilie',
'edithelppage'         => 'Help:Qualmen modificar un págine',
'helppage'             => 'Help:Auxilie',
'mainpage'             => 'Principal págine',
'mainpage-description' => 'Principal págine',
'portal'               => 'Págine del comunité',
'portal-url'           => 'Project:Págine del comunité',

'youhavenewmessages' => 'Vu have $1 ($2).',
'newmessageslink'    => 'nov missages',
'editsection'        => 'modificar',
'editold'            => 'redacter',
'editsectionhint'    => 'Modification de section: $1',
'toc'                => 'Tabelle de contenetes',
'showtoc'            => 'monstrar',
'hidetoc'            => 'celar',
'viewdeleted'        => 'Vider $1?',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Págine',
'nstab-user'      => 'Usator',
'nstab-project'   => 'Págine de projecte',
'nstab-mediawiki' => 'Missage',
'nstab-template'  => 'Modelle',
'nstab-help'      => 'Auxilie',
'nstab-category'  => 'Categorie',

# General errors
'error'      => 'Erra',
'viewsource' => 'Vider fonte',

# Login and logout pages
'logouttitle'                => 'Fine de session',
'logouttext'                 => 'Vu ha terminat vor session.
Vu posse continuar usar {{SITENAME}} anonimimen, o vu posse aperter un session denov quam li sam usator o quam un diferent usator.',
'loginpagetitle'             => 'Registrar se/Intrar',
'yourname'                   => 'Vor nómine usatori:',
'yourpassword'               => 'Vor passa-parol:',
'yourpasswordagain'          => 'Tippa denov vor passa-parol',
'remembermypassword'         => 'Memorar mi passa-parol (per cookie)',
'login'                      => 'Aperter session',
'nav-login-createaccount'    => 'Crear un conto o intrar',
'loginprompt'                => 'Cookies deve esser permisset por intrar in {{SITENAME}}.',
'userlogin'                  => 'Crear un conto o intrar',
'logout'                     => 'Surtir',
'userlogout'                 => 'Surtir',
'notloggedin'                => 'Vu ne ha intrat',
'createaccount'              => 'Crear un nov conto',
'gotaccountlink'             => 'Intrar',
'badretype'                  => 'Li passa-paroles queles vu tippat ne es identic.',
'youremail'                  => 'Vor ret-adresse:',
'loginerror'                 => 'Erra in initiation del session',
'nocookieslogin'             => '{{SITENAME}} utilisa cookies por far intrar usatores. Vu nu ne permisse cookies. Ples permisser les e provar denov.',
'loginsuccesstitle'          => 'Apertion de session successosi',
'loginsuccess'               => 'Vu ha apertet vor session in {{SITENAME}} quam "$1".',
'wrongpassword'              => 'Li passa-parol quel vu scrit es íncorect. Prova denov.',
'mailmypassword'             => 'Invia me un nov passa-parol per electronic post',
'acct_creation_throttle_hit' => 'Vu ja ha creat $1 contos. Vu ne posse crear pli mult quam to.',
'loginlanguagelabel'         => 'Lingue: $1',

# Password reset dialog
'oldpassword' => 'Anteyan passa-parol:',
'newpassword' => 'Nov passa-parol:',
'retypenew'   => 'Confirmar nov passa-parol',

# Edit pages
'summary'          => 'Resumate:',
'minoredit'        => 'Modification minori',
'watchthis'        => 'Sequer ti articul',
'savearticle'      => 'Conservar págine',
'preview'          => 'Previder',
'showpreview'      => 'Previder págine',
'loginreqtitle'    => 'Apertion de session obligatori',
'accmailtitle'     => 'Li passa-parol es inviat.',
'accmailtext'      => "Li passa-parol por '$1' ha esset inviat a $2.",
'newarticle'       => '(Nov)',
'editing'          => 'Modification de $1',
'editingsection'   => 'modification de $1 (section)',
'editingcomment'   => 'modification de $1 (comenta)',
'copyrightwarning' => "Omni contributiones a {{SITENAME}} es considerat quam publicat sub li termines del $2 (ples vider $1 por plu mult detallies). Si vu ne vole que vor ovres mey esser modificat e distribuet secun arbitrie, ples ne inviar les. Adplu, ples contribuer solmen vor propri ovres o ovres ex un fonte quel es líber de jures. '''NE UTILISA OVRES SUB JURE EDITORIAL SIN DEFINITIV AUTORISATION!'''",

# Diffs
'lineno' => 'Linea $1:',

# Search results
'viewprevnext'   => 'Vider ($1) ($2) ($3)',
'searchhelp-url' => 'Help:Auxilie',

# Preferences page
'preferences'    => 'Preferenties',
'mypreferences'  => 'Mi preferenties',
'prefsnologin'   => 'Vu ne ha intrat',
'qbsettings'     => 'Personalisation del barre de utensiles',
'changepassword' => 'Modificar passa-parol',
'saveprefs'      => 'Conservar preferenties',

# Groups
'group-user' => 'Usatores',

'group-user-member' => 'Usator',

'grouppage-user' => '{{ns:project}}:Usatores',

# Recent changes
'nchanges'          => '$1 {{PLURAL:$1|change|changes}}',
'recentchanges'     => 'Recent modificationes',
'recentchangestext' => 'Seque sur ti-ci págine li ultim modificationes al wiki.',
'rclistfrom'        => 'Monstrar li nov modificationes desde $1.',
'rcshowhideminor'   => '$1 modificationes minori',
'rcshowhidemine'    => '$1 mi redactiones',
'rclinks'           => 'Monstrar li $1 ultim modificationes fat durante li $2 ultim dies<br/ >$3.',
'diff'              => 'dif',
'hist'              => 'hist',
'hide'              => 'Celar',
'show'              => 'Monstrar',
'minoreditletter'   => 'm',

# Recent changes linked
'recentchangeslinked' => 'Relatet modificationes',

# Upload
'upload'    => 'Cargar file',
'uploadbtn' => 'Cargar file',
'filedesc'  => 'Descrition',
'savefile'  => 'Conservar file',

# Special:ListFiles
'listfiles' => 'Liste de images',

# File description page
'filehist-comment' => 'Comenta',

# Random page
'randompage' => 'Págine in hasarde',

# Statistics
'statistics' => 'Statisticas',

# Miscellaneous special pages
'ncategories'             => '$1 {{PLURAL:$1|categorie|categories}}',
'lonelypages'             => 'Orfani págines',
'uncategorizedpages'      => 'Págines sin categories',
'uncategorizedcategories' => 'Categories sin categories',
'unusedimages'            => 'Orfani images',
'wantedpages'             => 'Li max demandat págines',
'shortpages'              => 'Curt págines',
'longpages'               => 'Long págines',
'deadendpages'            => 'Págines sin exeada',
'listusers'               => 'Liste de usatores',
'newpages'                => 'Nov págines',
'ancientpages'            => 'Li max old págines',
'move'                    => 'Mover',

# Book sources
'booksources' => 'Librari fontes',

# Special:Log
'specialloguserlabel'  => 'Usator:',
'speciallogtitlelabel' => 'Titul:',

# Special:AllPages
'allpages'       => 'Omni págines',
'alphaindexline' => '$1 a $2',
'allarticles'    => 'Omni págines',
'allpagessubmit' => 'Vade',

# Special:Categories
'categories' => 'Categories',

# Watchlist
'watchlist'      => 'Liste de sequet págines',
'addedwatch'     => 'Adjuntet al liste',
'addedwatchtext' => "Li págine ''[[$1]]'' ha esset adjuntet a vor [[Special:Watchlist|liste de sequet págines]]. Li proxim modificationes de ti ci págine e del associat págine de discussion va esser listat ci, e li págine va aperir '''aspessat''' in li [[Special:RecentChanges|liste de recent modificationes]] por esser trovat plu facilmen. Por supresser ti ci págine ex vor liste, ples claccar sur « Ne plu sequer » in li cadre de navigation.",
'watch'          => 'Sequer',
'watchthispage'  => 'Sequer ti págine',

# Delete
'deletepage'            => 'Deleter págine',
'actioncomplete'        => 'Supression efectuat',
'deletecomment'         => 'Motive de deletion:',
'deleteotherreason'     => 'Altri/suplementari motive:',
'deletereasonotherlist' => 'Altri motive',

# Protect
'prot_1movedto2'   => '[[$1]] moet a [[$2]]',
'protectcomment'   => 'Comenta:',
'restriction-type' => 'Permission:',

# Namespace form on various pages
'blanknamespace' => '(Principal)',

# Contributions
'mycontris' => 'Mi contributiones',

# What links here
'whatlinkshere'      => 'Ligat págines',
'whatlinkshere-page' => 'Págine:',

# Block/unblock
'ipblocklist'  => 'Blocat adresses e usatores',
'contribslink' => 'contribs',

# Move page
'movearticle' => 'Moer págine:',
'movenologin' => 'Vu ne ha intrat',
'movepagebtn' => 'Moer págine',
'movedto'     => 'moet a',
'1movedto2'   => '[[$1]] moet a [[$2]]',
'movereason'  => 'Motive:',

# Export
'export' => 'Exportar págines',

# Namespace 8 related
'allmessages' => 'Liste del missages del sistema',

# Tooltip help for the actions
'tooltip-pt-mytalk'      => 'Vor discussion',
'tooltip-pt-preferences' => 'Mi preferenties',
'tooltip-ca-delete'      => 'Deleter ti págine',
'tooltip-ca-move'        => 'Moer ti págine',
'tooltip-n-mainpage'     => 'Visita li Principal págine',
'tooltip-t-specialpages' => 'Liste de omni special págines',

# Special:NewFiles
'newimages' => 'Galerie de nov images',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'omni',
'namespacesall' => 'omni',
'monthsall'     => 'omni',

# Special:Version
'version' => 'Version', # Not used as normal message but as header for the special page itself

# Special:SpecialPages
'specialpages' => 'Special págines',

);
